#### Online Appendix 12.1 ####

# load packages
  library(gplots)
  library(plotrix)
  library(segmented)
  library(AICcmodavg)
  library(nlme)
  library(MuMIn)

## part 1 - load and manipulate data
  
# load data
  FEMALE <- read.csv(file.choose())

# transform the variables Year and Study_Area to factor
  FEMALE$Year<- as.factor(FEMALE$Year)
  FEMALE$Study_Area <- as.factor(FEMALE$Study_Area)

# part 2 - calculate the scaled mass index (SMI) ####

# We use wing length as a measure of body size
  p2=cor.test(log(FEMALE$Weight),log(FEMALE$Wing), method = "pearson", use = "pairwise.complete.obs")
  lm <-lm(log(FEMALE$Weight) ~ log(FEMALE$Wing), data=FEMALE)
  c2=as.data.frame(lm$coefficients)
  bSMA2=c2[2,1]/p2$estimate
  FEMALE$SMI = FEMALE$Weight*(mean(FEMALE$Wing, na.rm=T)/FEMALE$Wing)^bSMA2

## part 3 - pre-laying dynamics of plasma TRIG 

# remove NA values for the variable TRIG
  FC <- (FEMALE[!is.na(FEMALE$TRIG),])

# calculate mean TRIG for each PLI value
  TRIG_m <- tapply(FC$TRIG, -(FC$PLI), mean)

# calculate standard deviation of TRIG for each PLI value
  TRIG_sd <- tapply(FC$TRIG, -(FC$PLI), sd)

# calculate sample size for each PLI value
  TRIG_N <- tapply(FC$TRIG, -(FC$PLI), length)

# calculate s.e.m. of TRIG for each PLI value
  TRIG_SE <- TRIG_sd/sqrt(TRIG_N)



# draw the plot
  par(mar = c(7,5,1,1)) # adjust margin of your plot
  plotCI(
    x = as.numeric(names(TRIG_N)), # x coordinates for the center of errors bars
    y = TRIG_m, # y coordinates for the center of errors bars
    uiw = TRIG_SE, # upper error bar length
    liw = TRIG_SE, # lower error bar length
    pch = 20, # plotting symbol 
    cex = TRIG_N, # symbol size multiplier. Here symbole size = number of observation for each PLI value
    col = "black", # color of the symbols and error bars
    xlim=c(-20,-1), # limits of the x-axis
    ylim=c(0,25), # limits of the y-axis
    sfrac = 0.01, # width of error bar as proportion of the plotting region
    xlab = "", # we will not display the labels on the x-axis for now
    ylab = expression(" plasma TRIG" ~ (mmol. ~ L^{-1})), # labels of the y-axis
    cex.lab = 1.5, # Size of the labels on x- and y-axes
    axes=FALSE, # By indicating FALSE, axes are hidden (we will add them manually below)
    las = 1 # display axis labels horizontally
     )

# add graduations on the x-axis
  Axis(side = 1, at=(seq(-20,-2,1)), labels =F)
  labpos = c( -20, -15,-10,-5,-2)
  Axis(side=1, at=labpos, labels=c( 20, 15,10,5,2), cex.axis=1.5)

# add graduations on the y-axis
  Axis(side = 2, at=(seq(0,25,1)), labels =F)
  labpos = c(0,5,10,15,20,25)
  Axis(side=2, at=labpos, labels=c(0,5,10,15,20,25), cex.axis=1.5, las = 1)

# add labels on the x-axis
  mtext(side  = 1, line = 5, text = "Pre-laying interval (days)", at = mean(c(-20,-1)), cex = 1.5)
  mtext(side  =  1,  line  = 2.5 ,  text  =  "PR", at = -15, cex = 1)
  mtext(side = 1, line = 2.5, text = "RFG", at = -5.5, cex =1)

# add basic polygons to show the separation between the PR and RFG periods
  par(xpd = NA)
  polygon(x  = c(-20, -20, -9.75,-9.75),  y  = c(-5.0, -4.7, -4.7,  -5.0), col = "white", lwd = 1) 
  polygon(x  = c(-9.25, -9.25, -2,-2),  y  = c(-5.0, -4.7, -4.7,  -5.0), col = "white", lwd = 1)

# look for breakpoint in the regression between TRIG and PLI

# transform PLI from positive to negative values
  FEMALE$PLIneg <- -FEMALE$PLI 

# create a linear model using raw data
  lm1<-lm(TRIG ~ PLIneg, FEMALE)

# ask the segmented function to look for a breakpoint around the PLIneg value specified by the psi argument
  Seg <- segmented(lm1, seg.Z = ~ PLIneg, psi = -7, it.max = 1000)

# if the function converged to a breakpoint, you can get the value
  Seg$psi[2]

# and the standard error of the estimated breakpoint value
  Seg$psi[3]

# add a shaded area to the plot that encloses the breakpoint +- standard error
  polygon(x= c(Seg$psi[2]-Seg$psi[3],Seg$psi[2]-Seg$psi[3],Seg$psi[2]+Seg$psi[3],Seg$psi[2]+Seg$psi[3]),
        y = c(-1,25,25,-1), col = "gray94", border = "white")
  lines(x = c(Seg$psi[2]+Seg$psi[3],Seg$psi[2]+Seg$psi[3]), y = c(-1,25), col = "lightgray", lwd = 1, lty = 2)
  lines(x = c(Seg$psi[2]-Seg$psi[3],Seg$psi[2]-Seg$psi[3]), y = c(-1,25), col = "lightgray", lwd = 1, lty = 2)
  lines(x = c(Seg$psi[2],Seg$psi[2]), y = c(-1,25), col = "darkgray", lwd = 1, lty = 1)
  lines(x = c(-15,-2), y = c(-1,-1))

# plot the data again to display the points over the shaded area 
  plotCI(
    x = as.numeric(names(TRIG_N)), 
    y = TRIG_m, 
    uiw = TRIG_SE, 
    liw = TRIG_SE, 
    pch = 20,
    cex = TRIG_N, 
    col = "black",
    sfrac = 0.01,
    add = T
  )

# fit a linear regression before and after the estimated breakpoint for the relationship between plasma TRIG and PLI
  summary(lm(TRIG ~ PLIneg, data = FEMALE[FEMALE$PLIneg < Seg$psi[2],])) 
  summary(lm(TRIG ~ PLIneg, data = FEMALE[FEMALE$PLIneg > Seg$psi[2],])) 

## part 4 - linking pre-laying physiological condition to reproductive phenology ######

# remove observations with NA values for the variables of interest
  FEMALE <- FEMALE[!is.na(FEMALE$TRIG & FEMALE$BUTY & FEMALE$CORT & FEMALE$SMI & FEMALE$PLI),]

# create a subset with pre-recruiting females only
  FEMALEPR <- subset(FEMALE, Stage == "PR")

# ccreate simple models testing only for a random intercept of the factors Study Area and Year
  lmm1 <- lme(PLI ~ 1, random = ~1|Study_Area, data = FEMALEPR)
  lmm2 <- lme(PLI ~ 1, random = ~1|Year, data = FEMALEPR)
  lmm3 <- lme(PLI ~ 1, random = ~1|Study_Area/Year, data = FEMALEPR)
  mod <- list(lmm1,lmm2,lmm3)
  names <- c("Study_Area", "Year", "Study_Area/Year") 

# compare these models using the aictab function available in the AICcmodavg library. The argument second.ord = T allows model ranking based on AICc. The warning message indicates that mdoels are fitted using restricted log-likelihood
  aictab(cand.set = mod, modnames = names, sort = TRUE, second.ord = T)

# Create a function called AICc. This function uses the aictab function in the AICcmodavg package to rank candidate models. The argument second.ord = T allows model ranking based on AICc
  AICc <- function (FEMALEPR)
  {
    mod <-list()
    mod[[1]] = lme(scale(PLI) ~ 1, random = ~1|Study_Area , data = FEMALEPR, method = "ML")
    mod[[2]] = lme(scale(PLI) ~ scale(log(BUTY)),random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[3]] = lme(scale(PLI) ~ scale(CORT),random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[4]] = lme(scale(PLI) ~ scale(TRIG),random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[5]] = lme(scale(PLI) ~ scale(log(BUTY)) + scale(TRIG),random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[6]] = lme(scale(PLI) ~ scale(TRIG) + scale(CORT),random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[7]] = lme(scale(PLI) ~ scale(SMI), random = ~1|Study_Area, data = FEMALEPR, method = "ML")
    mod[[8]] = lme(scale(PLI) ~ scale(SMI) + scale(log(BUTY)), random = ~1|Study_Area,data = FEMALEPR, method = "ML")
    mod[[9]] = lme(scale(PLI) ~ scale(SMI) + scale(CORT), random = ~1|Study_Area,data = FEMALEPR, method = "ML")
    mod[[10]] = lme(scale(PLI) ~ scale(SMI) + scale(TRIG), random = ~1|Study_Area,data = FEMALEPR, method = "ML")
  
  Modnames<-paste("mod", 1:length(Mod), sep="")
  Names = c( 
    "NULL", #1
    "log BUTY",   #2
    "CORT",      #3
    "TRIG", #4
    "log BUTY + TRIG", #5
    "TRIG + CORT",  #6
    "SMI", #7
    "SMI + log BUTY", #8
    "SMI + CORT", #9
    "SMI + TRIG" #10
  )
  return (aictab(cand.set = mod, modnames = Names, sort = TRUE, second.ord = T)) 
}

# apply the function over our data set
  results_PLI <- AICc(FEMALEPR) 

  print(results_PLI)

# summary of the most parsimonious model
  summary(lme((PLI) ~ (TRIG), random = ~1|Study_Area, data = FEMALEPR, method = "ML"))
